@@ -1,5 +1,3 @@
-#!/usr/bin/python
-
 '''apport hook for bind9
 
 (c) 2010 Andres Rodriguez.
@@ -16,19 +14,11 @@ from apport.hookutils import *
 import re
 
 def add_info(report, ui):
-    response = ui.yesno("The contents of your /etc/bind/named.conf file "
-                        "may help developers diagnose your bug more "
-                        "quickly.  However, it may contain sensitive "
-                        "information.  Do you want to include it in your "
-                        "bug report?")
-
-    if response == None: # user cancelled
-        raise StopIteration
-    elif response == True:
-        attach_conffiles(report,'bind9')
 
     # getting syslog stuff
     report['SyslogBind9'] = recent_syslog(re.compile(r'named\['))
 
     # Attaching related packages info
     attach_related_packages(report, ['bind9utils', 'apparmor'])
+
+    attach_mac_events(report, '/usr/sbin/named')
